@@ -2,24 +2,15 @@ p_nca_cr_vrs <-
 function (loop.data, bn.data) {
   x <- loop.data$x
   y <- loop.data$y
-  flip.x <- loop.data$flip.x
-  flip.y <- loop.data$flip.y
-  weighting <- loop.data$weighting
 
   # Find the points on the ceiling ("PEERS")
-  peers <- p_peers(loop.data, TRUE)
+  peers <- p_peers(loop.data, vrs=TRUE)
 
   if (!is.vector(peers) && length(peers) > 2) {
-    # Get the weights if resuired
-    weights <- NULL
-    if (weighting) {
-      weights <- p_weights(loop.data, peers)
-    }
-
     # Perform OLS through the peers
     x <- peers[,1]
     y <- peers[,2]
-    line <- lm(y~x, weights=weights)
+    line <- lm(y~x)
     
     intercept <- unname(coef(line)["(Intercept)"])
     slope     <- unname(coef(line)["x"])
@@ -34,12 +25,14 @@ function (loop.data, bn.data) {
   }
   
   effect      <- ceiling / loop.data$scope.area
+  accuracy    <- p_accuracy(loop.data, above)
+  fit         <- get_fit(ceiling, loop.data$ce_fdh_ceiling)
   ineffs      <- p_ineffs(loop.data, slope, intercept)
   bottleneck  <- p_bottleneck(loop.data, bn.data, slope, intercept)
-  
+
   return(list(line=line,
               slope=slope, intercept=intercept,
               ceiling=ceiling, effect=effect,
-              ineffs=ineffs, above=above,
-              bottleneck=bottleneck))
+              above=above, accuracy=accuracy, fit=fit,
+              ineffs=ineffs, bottleneck=bottleneck))
 }
\ No newline at end of file
