@@ -109,3 +109,45 @@ function (peers, x3, y3, flip.x, flip.y) {
     return (slope0 >= slope1)
   }
 }
+
+p_method_peers <- function (peers, plots, methods) {
+  handled <- c("ce_vrs", "ce_fdh", "ols", "cols",
+               "qr", "cr_vrs", "cr_fdh", "c_lp")
+  diff <- setdiff(handled, ceilings)
+  if (length(diff) != 0) {
+    stop("Not all ceilings are handled in p_method_peers")
+  }
+
+  method_peers <- list()
+  for (method in methods) {
+    if (method %in% c("ols", "qr", "cols")) {
+      next
+    }
+    if (method %in% c("ce_fdh", "cr_fdh")) {
+      method_peers[[method]] <- peers
+    }
+    if (method %in% c("ce_vrs", "cr_vrs", "c_lp")) {
+      tmp_list <- list()
+      for (x.name in names(plots)) {
+        plot <- plots[[x.name]]
+        loop.data <- list(x=plot$x, y=plot$y,
+                          flip.x=plot$flip.x, flip.y=plot$flip.y)
+        df <- p_peers(loop.data, vrs = TRUE)
+
+        if (method == 'c_lp') {
+          intercept <- plot$lines$c_lp[1]
+          scope <- plot$lines$c_lp[2]
+          df <- cbind(df, abs(intercept + scope * df[, 1] - df[, 2]))
+          df <- df[order(df[, 3]),]
+          df <- df[c(1, 2), c(1, 2)]
+        }
+
+        if (!is.null(df)) {
+          tmp_list[[x.name]] <- df
+        }
+      }
+      method_peers[[method]] <- tmp_list
+    }
+  }
+  return(method_peers)
+}
